@@ -227,6 +227,7 @@ class ProdutoPreco(core.models.Log):
     valor = models.DecimalField(max_digits=14, decimal_places=2, null=True)
 
     precolista = models.ForeignKey('produto.PrecoLista', on_delete=models.DO_NOTHING, null=True)
+    desconto = models.ManyToManyField('produto.Desconto', through='produto.DescontoProdutoPreco', through_fields=('produtopreco', 'desconto'))
 
     class Meta(core.models.Log.Meta):
         abstract = False
@@ -257,19 +258,13 @@ class Desconto(core.models.Log):
         db_table = 'produto_desconto'
 
 
-class DescontoRelacao(core.models.Log):
+class DescontoProdutoPreco(core.models.Log):
     desconto = models.ForeignKey('produto.Desconto', on_delete=models.DO_NOTHING, null=True)
-
-    produto = models.ForeignKey('produto.Produto', on_delete=models.DO_NOTHING, null=True)
     produtopreco = models.ForeignKey('produto.ProdutoPreco', on_delete=models.DO_NOTHING, null=True)
-    categoria = models.ForeignKey('produto.Categoria', on_delete=models.DO_NOTHING, null=True)
-    precolista = models.ForeignKey('produto.PrecoLista', on_delete=models.DO_NOTHING, null=True)
-    grupo = models.ForeignKey('produto.Grupo', on_delete=models.DO_NOTHING, null=True)
-    marca = models.ForeignKey('produto.Marca', on_delete=models.DO_NOTHING, null=True)
 
     class Meta(core.models.Log.Meta):
         abstract = False
-        db_table = 'produto_descontorelacao'
+        db_table = 'produto_descontoprodutopreco'
 
 
 class Estoque(core.models.Log):
